#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-hash
version:              0.2.0.1
visibility:           public
id:                   data-hash-0.2.0.1-LkMc0bqAeQBxfk0jyLwD8
key:                  data-hash-0.2.0.1-LkMc0bqAeQBxfk0jyLwD8
license:              BSD-3-Clause
maintainer:           jcpetruzza@gmail.com
synopsis:             Combinators for building fast hashing functions.
description:
    Combinators for building fast hashing functions. Includes
    hashing functions for all basic Haskell98 types.

category:             Data
abi:                  c306226009b6c654135c6bf3bca3840f
exposed:              True
exposed-modules:      Data.Hash Data.Hash.Rolling
hidden-modules:       Data.Hash.Base Data.Hash.Instances
import-dirs:          /usr/lib/ghc-8.10.5/site-local/data-hash-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/data-hash-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/data-hash-0.2.0.1
hs-libraries:         HSdata-hash-0.2.0.1-LkMc0bqAeQBxfk0jyLwD8
depends:              array-0.5.4.0 base-4.14.2.0 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-data-hash/html/data-hash.haddock
haddock-html:         /usr/share/doc/haskell-data-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

